:orphan:

Tutorials
=========

Tutorials for installation, library and commandline usage. New users start here.

.. toctree::
    :caption: Tutorials
    
    tutorials/01-setup
    tutorials/02-orientation
    tutorials/03-variables
    tutorials/04-loops
    tutorials/05-if-then
    tutorials/06-functions
    tutorials/07-lists
    tutorials/08-dictionaries
    tutorials/09-classes
    